diff Core/PalanthirException.h @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 491a97842e31
children
line wrap: on
line diff
--- a/Core/PalanthirException.h	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/PalanthirException.h	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,9 +23,9 @@
 #include <string>
 #include "Enumerations.h"
 
-namespace Palantir
+namespace Palanthir
 {
-  class PalantirException
+  class PalanthirException
   {
   private:
     ErrorCode error_;
@@ -34,13 +34,13 @@
   public:
     static const char* GetDescription(ErrorCode error);
 
-    PalantirException(const std::string& custom)
+    PalanthirException(const std::string& custom)
     {
       error_ = ErrorCode_Custom;
       custom_ = custom;
     }
 
-    PalantirException(ErrorCode error)
+    PalanthirException(ErrorCode error)
     {
       error_ = error;
     }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium